@@ -74,14 +74,14 @@
 // Construct the main application window
 KWin4App::KWin4App(QWidget *parent)
         : KXmlGuiWindow(parent),
-          mTheme(nullptr),
-          mView(nullptr),
-          mDoc(nullptr),
-          mScene(nullptr),
-          mColorGroup(nullptr),
-          mMyChatDlg(nullptr),
-          mStatusMsg(nullptr),
-          mStatusMover(nullptr)
+          mTheme(),
+          mView(),
+          mDoc(),
+          mScene(),
+          mColorGroup(),
+          mMyChatDlg(),
+          mStatusMsg(),
+          mStatusMover()
 {
   // default names for players
   (void)I18N_NOOP2("default name of first player", "Player 1");
@@ -89,10 +89,10 @@ KWin4App::KWin4App(QWidget *parent)
 
   // Read theme files
   QStringList themeList;
-  const QString dir = QStandardPaths::locate(QStandardPaths::DataLocation, "grafix", QStandardPaths::LocateDirectory);
+  const QString dir = QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("grafix"), QStandardPaths::LocateDirectory);
   const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.desktop"));
   for (const QString& file : fileNames)
-    themeList.append(dir + '/' + file);
+    themeList.append(dir + QLatin1Char('/') + file);
 
   if (themeList.isEmpty())
   {
@@ -406,7 +406,7 @@ void KWin4App::changeAction(const char* action, bool enable)
     return;
   }
 
-  QAction* act=actionCollection()->action(action);
+  QAction* act=actionCollection()->action(QLatin1String(action));
   if (act)
   {
     act->setEnabled(enable);
@@ -421,7 +421,7 @@ void KWin4App::saveProperties(KConfigGroup& grp)
 
   // Save current game?
   QString name = QStringLiteral("current_game")+grp.name();
-  QString filename = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + '/' + name;
+  QString filename = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + name;
   bool isRunning = (mDoc->gameStatus()==KGame::Run);
   if (isRunning)
   {
@@ -781,7 +781,7 @@ void KWin4App::configureNetwork()
   int port=Prefs::port();
 
   // just for testing - should be non-modal
-  KGameDialog dlg(mDoc, 0, i18n("Network Configuration"), this);
+  KGameDialog dlg(mDoc, nullptr, i18n("Network Configuration"), this);
   dlg.networkConfig()->setDefaultNetworkInfo(host, port);
   dlg.networkConfig()->setDiscoveryInfo(QStringLiteral("_kfourinline._tcp"),Prefs::gamename());
 
@@ -866,7 +866,7 @@ void KWin4App::configureSettings()
   static Ui::Settings ui; // Dialog is internally static anyway
   if(KConfigDialog::showDialog(QStringLiteral("settings")))
   {
-    // The dialog need to refresh the buttons as they are not conectable via a signal-slot 
+    // The dialog need to refresh the buttons as they are not connectable via a signal-slot 
     // in KConfigDialog
     ui.kcfg_startcolourred->setChecked(Prefs::startcolourred());
     ui.kcfg_startcolourred->setText(mTheme->colorNamePlayer(0));
