@@ -20,24 +20,25 @@
 
 // Header includes
 #include "pixmapsprite.h"
+#include "kfourinline_debug.h"
 
 // General includes
-#include <math.h>
+#include <cmath>
 
 // Qt includes
 #include <QGraphicsScene>
+
 // KDE includes
-#include "kfourinline_debug.h"
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KConfig>
+#include <KConfigGroup>
 
 // Constructor for the sprite
 PixmapSprite::PixmapSprite(const QString &id, ThemeManager* theme, int no, QGraphicsScene* canvas)
-    :  Themeable(id, theme), QGraphicsPixmapItem(0)
+    :  Themeable(id, theme), QGraphicsPixmapItem()
 {
   canvas->addItem(this);
   hide();
-  setAcceptsHoverEvents(false);
+  setAcceptHoverEvents(false);
 
   mAnimationState = Idle;
   mNo             = no;
@@ -50,7 +51,7 @@ PixmapSprite::PixmapSprite(const QString &id, ThemeManager* theme, int no, QGrap
 
 // Constructor for the sprite
 PixmapSprite::PixmapSprite(int no, QGraphicsScene* canvas)
-    :  Themeable(), QGraphicsPixmapItem(0)
+    :  Themeable(), QGraphicsPixmapItem()
 {
   canvas->addItem(this);
   hide();
@@ -63,7 +64,7 @@ PixmapSprite::PixmapSprite(int no, QGraphicsScene* canvas)
 
 
 // Main themeable function. Called for any theme change. The sprites needs to
-// resiez and redraw here.
+// resize and redraw here.
 void PixmapSprite::changeTheme()
 {
   // Clear data
@@ -152,10 +153,10 @@ void PixmapSprite::changeTheme()
     else mHotspots.append(QPointF(0.0,0.0));
   }
   
-  // Set theme offset (probably not really necesary here)
+  // Set theme offset (probably not really necessary here)
   QPoint offset = thememanager()->getOffset();
   resetTransform();
-  if (mOffsetStatus) translate(offset.x(), offset.y());
+  if (mOffsetStatus) setTransform(QTransform::fromTranslate(offset.x(), offset.y()), true);
 
   // Set pixmap to sprite
   setFrame(mCurrentFrame, true);
@@ -235,11 +236,11 @@ void PixmapSprite::setFrame(int no, bool force)
   resetTransform();
   if (mOffsetStatus)
   {
-    translate(-mHotspots.at(no).x()+offset.x(), -mHotspots.at(no).y()+offset.y());
+    setTransform(QTransform::fromTranslate(-mHotspots.at(no).x()+offset.x(), -mHotspots.at(no).y()+offset.y()), true);
   }
   else 
   {
-    translate(-mHotspots.at(no).x(), -mHotspots.at(no).y());
+    setTransform(QTransform::fromTranslate(-mHotspots.at(no).x(), -mHotspots.at(no).y()), true);
   }
   mCurrentFrame = no;
   update();
